#!/usr/bin/env python
"""
Python module info - display system and python info

Note: This "debug" extension does not depend on inkex.py 
or other python modules usually required by Inkscape's 
python-based extension scripts: it tries to import 
required python modules and informs if this fails.

Copyright (C) 2010-2012 ~suv, suv-sf@users.sourceforge.net

Contributors:
    Craig Marshall (2010)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
"""

# standard library
import sys

def errormsg(msg):
    if isinstance(msg, unicode):
        sys.stderr.write((msg).encode("UTF-8") + "\n")
    else:
        sys.stderr.write((unicode((msg), "utf-8", errors='replace') + "\n").encode("UTF-8"))

def p(msg): # print
    errormsg(msg)

def l(): # line
    errormsg("-"*40)

def d(ints): # dotted
    return ".".join([str(i) for i in ints if i != ""])

def system_info():
    try:
        import sys
        paths = "\n\t" + "\n\t".join(sys.path)
        #environs = "\n\t" + "\n\t".join(os.environ)
        p("Default Encoding: " + sys.getdefaultencoding())
        l()
        p("Filesystem Encoding: " + sys.getfilesystemencoding())
        l()
        try:
            p("Windows Version: " + sys.getwindowsversion())
            l()
        except AttributeError:
            pass
        p("Platform: " + sys.platform)
        l() 
        p("Python sys.version_info: %s" % d(sys.version_info[:3]))
        p("Python sys.version: \n%s" % sys.version)
        l()
        p("Python sys.executable: \n\t%s" % sys.executable)
        p("Python sys.exec_prefix: \n\t %s" % sys.exec_prefix)
        p("Python sys.prefix: \n\t%s" % sys.prefix)
        l()
        p("sys.path: " + paths)
    except Exception, e:
        p("module sys failed to load.")

def lxml_info():
    try:
        import lxml
        from lxml import etree
        p("lxml path: %s" % lxml.__path__[0])
        p("LXML_VERSION: %s" % d(etree.LXML_VERSION))
        p("LIBXML_VERSION: %s" % d(etree.LIBXML_VERSION))
        p("LIBXML_COMPILED_VERSION: %s" % d(etree.LIBXML_COMPILED_VERSION))
        p("LIBXSLT_VERSION: %s" % d(etree.LIBXSLT_VERSION))
        p("LIBXSLT_COMPILED_VERSION: %s" % d(etree.LIBXSLT_COMPILED_VERSION))   
    except Exception, e:
        p("The fantastic lxml wrapper for libxml2 is required by this extension.\n\nTechnical details:\n%s" % (e,))

def numpy_info():
    try:
        import numpy
        p("numpy path: %s" % numpy.__path__[0])
        p("numpy version: %s" % numpy.__version__)  
    except Exception, e:
        p("numpy is required by this extension.\n\nTechnical details:\n%s" % (e,))

def environ_info():
    try:
        import os
        p("os.environ: ")
        for param in os.environ.keys(): 
            p("%s \n\t%s" % (param,os.environ[param]))
    except Exception, e:
        p("module sys failed to load.")

def foo_info():
    try:
        from foo import bar
        p("bar from foo imported")
    except Exception, e:
        p("bar from foo failed to load.")

class Effect:
    """A class for creating Inkscape SVG Effects"""

    def affect(self):
        self.effect()

class DebugInkscapeExtensions(Effect):

    def effect(self):
        system_info()
        l()
        lxml_info()
        l()
        numpy_info()
        l()
        environ_info()
        l()
        foo_info()
        l()

effect = DebugInkscapeExtensions()
effect.affect()

# vim: expandtab shiftwidth=4 tabstop=8 softtabstop=4 fileencoding=utf-8 textwidth=99
